@@ -8,7 +8,8 @@
 #' @param y response
 #' @param yhat fitted value
 #'
-#' @seealso \code{\link{cv}}, \code{\link{cvSelect}}
+#' @seealso \code{\link{cv}}, \code{\link{cv.merMod}},
+#' \code{\link{cv.function}}.
 #'
 #' @details
 #' Cost functions (cross-validation criteria) are meant to measure lack-of-fit. Several cost functions are provided:
@@ -28,11 +29,11 @@
 #' the latter doesn't and is therefore faster.
 #'
 #' @returns In general, cost functions should return a single numeric
-#' value measuring lack-of-fit. `mse()` returns the mean-squared error;
-#' `rmse()` returns the root-mean-squared error;
-#' `medAbsErr()` returns the median absolute error;
-#' and BayesRule()` and
-#' `BayesRule2()` return the proportion of misclassified cases.
+#' value measuring lack-of-fit. \code{mse()} returns the mean-squared error;
+#' \code{rmse()} returns the root-mean-squared error;
+#' \code{medAbsErr()} returns the median absolute error;
+#' and \code{BayesRule()} and
+#' \code{BayesRule2()} return the proportion of misclassified cases.
 #' @examples
 #' data("Duncan", package="carData")
 #' m.lm <- lm(prestige ~ income + education, data=Duncan)
@@ -42,41 +43,44 @@
 #' m.glm <- glm(lfp ~ ., data=Mroz, family=binomial)
 #' BayesRule(Mroz$lfp == "yes", fitted(m.glm))
 
-#' @describeIn cost-functions Mean-square error
+#' @describeIn cost-functions Mean-square error.
 #' @export
-mse <- function(y, yhat){
-  result <- mean((y - yhat)^2)
+mse <- function(y, yhat) {
+  result <- mean((y - yhat) ^ 2)
   attr(result, "casewise loss") <- "(y - yhat)^2"
   result
 }
 
-#' @describeIn cost-functions Root-mean-square error
+#' @describeIn cost-functions Root-mean-square error.
 #' @export
-rmse <- function(y, yhat){
-  sqrt(mean((y - yhat)^2))
+rmse <- function(y, yhat) {
+  sqrt(mean((y - yhat) ^ 2))
 }
 
-#' @describeIn cost-functions Median absolute error
+#' @describeIn cost-functions Median absolute error.
 #' @importFrom stats median
 #' @export
-medAbsErr <- function(y, yhat){
+medAbsErr <- function(y, yhat) {
   median(abs(y - yhat))
 }
 
-#' @describeIn cost-functions Bayes Rule for a binary response
+#' @describeIn cost-functions Bayes Rule for a binary response.
 #' @export
-BayesRule <- function(y, yhat){
-  if (!all(y %in% c(0, 1))) stop("response values not all 0 or 1")
-  if (any(yhat < 0) || any(yhat > 1)) stop("fitted values outside of interval [0, 1]")
+BayesRule <- function(y, yhat) {
+  if (!all(y %in% c(0, 1)))
+    stop("response values not all 0 or 1")
+  if (any(yhat < 0) ||
+      any(yhat > 1))
+    stop("fitted values outside of interval [0, 1]")
   yhat <- round(yhat)
   result <- mean(y != yhat) # proportion in error
   attr(result, "casewise loss") <- "y != round(yhat)"
   result
 }
 
-#' @describeIn cost-functions Bayes rule for a binary response (without bounds checking)
+#' @describeIn cost-functions Bayes rule for a binary response (without bounds checking).
 #' @export
-BayesRule2 <- function(y, yhat){
+BayesRule2 <- function(y, yhat) {
   yhat <- round(yhat)
   result <- mean(y != yhat) # proportion in error
   attr(result, "casewise loss") <- "y != round(yhat)"
